.. _evaluation:


Evaluation
**********

.. currentmodule:: torchkge.evaluation

Link Prediction
---------------
.. automodule:: torchkge.evaluation.LinkPrediction

.. autoclass:: torchkge.evaluation.LinkPrediction.LinkPredictionEvaluator
    :members:

Triplet Classification
----------------------
.. automodule:: torchkge.evaluation.TripletClassification

.. autoclass:: torchkge.evaluation.TripletClassification.TripletClassificationEvaluator
    :members:
